/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.document.index.persistence.impl;

import com.topcoder.document.index.persistence.IndexPersistenceException;

import junit.framework.TestCase;


/**
 * <p>
 * Unit test cases for <code>PersistenceConfigurationException</code>.
 * </p>
 *
 * <p>
 * This class is pretty simple. The test cases verify the exception can be instantiated with the error message and
 * cause properly propagated, and that it comes with correct inheritance.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 1.0
 */
public class PersistenceConfigurationExceptionUnitTest extends TestCase {
    /**
     * <p>
     * The error message used for testing.
     * </p>
     */
    private static final String ERROR_MESSAGE = "test error message";

    /**
     * <p>
     * Creation test.
     * </p>
     *
     * <p>
     * Verifies the error message is properly propagated.
     * </p>
     */
    public void testPersistenceConfigurationException1() {
        PersistenceConfigurationException ce = new PersistenceConfigurationException(ERROR_MESSAGE);

        assertNotNull("Unable to instantiate PersistenceConfigurationException.", ce);
        assertEquals("Error message is not properly propagated to super class.", ERROR_MESSAGE, ce.getMessage());
    }

    /**
     * <p>
     * Creation test.
     * </p>
     *
     * <p>
     * Verifies the error message and the cause are properly propagated.
     * </p>
     */
    public void testPersistenceConfigurationException2() {
        Throwable cause = new Throwable();
        PersistenceConfigurationException ce = new PersistenceConfigurationException(ERROR_MESSAGE, cause);

        assertNotNull("Unable to instantiate PersistenceConfigurationException.", ce);
        assertEquals("Cause is not properly propagated to super class.", cause, ce.getCause());
    }

    /**
     * <p>
     * Inheritance test.
     * </p>
     *
     * <p>
     * Verifies <code>PersistenceConfigurationException</code> subclasses <code>IndexPersistenceException</code>.
     * </p>
     */
    public void testPersistenceConfigurationExceptionInheritance1() {
        assertTrue("PersistenceConfigurationException does not subclass IndexPersistenceException.",
            new PersistenceConfigurationException(ERROR_MESSAGE) instanceof IndexPersistenceException);
    }

    /**
     * <p>
     * Inheritance test.
     * </p>
     *
     * <p>
     * Verifies <code>PersistenceConfigurationException</code> subclasses <code>IndexPersistenceException</code>.
     * </p>
     */
    public void testPersistenceConfigurationExceptionInheritance2() {
        assertTrue("PersistenceConfigurationException does not subclass IndexPersistenceException.",
            new PersistenceConfigurationException(ERROR_MESSAGE, new Throwable()) instanceof IndexPersistenceException);
    }
}
